aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/vnet.h
diff options
context:
space:
mode:
authorDamjan Marion <damarion@cisco.com>2021-03-04 18:41:59 +0100
committerOle Tr�an <otroan@employees.org>2021-03-05 11:59:24 +0000
commit8fb5add31885fcee1abaf60dd903aa566cc53b0d (patch)
tree774eddc57568e5cad1cb3c2d4a4956501d21a37b /src/vnet/vnet.h
parent3efd4e9998192545c32aeb33a9f8f72a1ba085a9 (diff)
interface: move vnet_pcap_t to vnet
It naturally belogns there... Type: refactor Change-Id: I05f7ba01103a5e9b3756f1ea69c8cc5d8f26f0a0 Signed-off-by: Damjan Marion <damarion@cisco.com>
Diffstat (limited to 'src/vnet/vnet.h')
-rw-r--r--src/vnet/vnet.h30
1 files changed, 24 insertions, 6 deletions
diff --git a/src/vnet/vnet.h b/src/vnet/vnet.h
index be680a77f98..38777b9b24f 100644
--- a/src/vnet/vnet.h
+++ b/src/vnet/vnet.h
@@ -57,6 +57,21 @@ typedef struct _vnet_ip_table_function_list_elt
clib_error_t *(*fp) (struct vnet_main_t * vnm, u32 table_id, u32 flags);
} _vnet_ip_table_function_list_elt_t;
+typedef struct
+{
+ /* Trace RX pkts */
+ u8 pcap_rx_enable;
+ /* Trace TX pkts */
+ u8 pcap_tx_enable;
+ /* Trace drop pkts */
+ u8 pcap_drop_enable;
+ u8 pad1;
+ u32 max_bytes_per_pkt;
+ u32 pcap_sw_if_index;
+ pcap_main_t pcap_main;
+ u32 filter_classify_table_index;
+} vnet_pcap_t;
+
typedef struct vnet_main_t
{
u32 local_interface_hw_if_index;
@@ -83,13 +98,16 @@ typedef struct vnet_main_t
_vnet_ip_table_function_list_elt_t
* ip_table_add_del_functions[VNET_ITF_FUNC_N_PRIO];
- /*
- * Last "api" error, preserved so we can issue reasonable diagnostics
- * at or near the top of the food chain
- */
- vnet_api_error_t api_errno;
+ /* pcap rx / tx tracing */
+ vnet_pcap_t pcap;
+
+ /*
+ * Last "api" error, preserved so we can issue reasonable diagnostics
+ * at or near the top of the food chain
+ */
+ vnet_api_error_t api_errno;
- vlib_main_t *vlib_main;
+ vlib_main_t *vlib_main;
} vnet_main_t;
extern vnet_main_t vnet_main;